#!/bin/bash
#
# Winco Tecnologia e Sistemas
#
# ddns.sh - v.1.5
#
################################################################
#
# Este script estabelece o IP de um dominio DDNS
#
################################################################
#
# As seguintes variaveis devem ser configuradas:

# Coloque aqui seu dominio DDNS 
# (ex.: meuendereco.ddns.com.br)
DOMINIO=""

# A senha para o dominio acima
SENHA=""

# Coloque aqui o IP em caso de IP fixo
IP=""

# Se o dominio esta atras de um NAT, use "yes" abaixo, para que 
# o IP publico de seu roteador seja atribuido ao dominio. Neste 
# caso a inerface usada sera aquela que leva ao roteador padrao.
USENAT=""

# ou especifique da interface. Ex.: ppoe, eth0, etc
INTERFACE=""

#Diretorio temporario
TMPDIR=/tmp

#diretorio de instalacao do DDNS
BINDIR=/usr/local/bin

getip()
{
	if [ "$IP" != "" ]; then
		echo $IP
	elif [ "$USENAT" = "yes" ]; then
		NAMESERVERNAME=`${BINDIR}/ddnsquery -t NS ddns.com.br | \
							grep '[[:space:]]*NS[[:space:]]*' | \
							grep -o '[a-zA-Z0-9\-]*\.[a-zA-Z0-9\-]*\.[a-zA-Z0-9\-]*\.[a-zA-Z0-9\-]*$' | \
							head -1`
		NAMESERVER=`${BINDIR}/ddnsquery ${NAMESERVERNAME} | grep -o '[0-9]*\.[0-9]*\.[0-9]*\.[0-9]*' | head -1`
		${BINDIR}/ddnsquery -t MYIP -n $NAMESERVER www.ddns.com.br | grep -o '[0-9]*\.[0-9]*\.[0-9]*\.[0-9]*' | head -1
	else
		LANG= /sbin/ifconfig $INTERFACE | grep 'inet ' | grep -o '[0-9]*\.[0-9]*\.[0-9]*\.[0-9]*' | head -1
	fi
}

setip()
{
	if ( grep : <<< $3 > /dev/null 2>&1 ) then
		TYPE=-i
	else
		TYPE=-a
	fi
	${BINDIR}/ddnsquery -t SET $TYPE $3 -p $1 $2
}

refresh()
{
	# Isso forca refresh no ddns.sh
	echo "0.0.0.0" >  ${TMPDIR}/ddns.ip
}

setup()
{
	# Se o arquivo  ${TMPDIR}/ddns.ip no existe, cria-lo com 0.0.0.0
	if [ ! -e  ${TMPDIR}/ddns.ip ]; then
		echo "0.0.0.0" >  ${TMPDIR}/ddns.ip
	fi

	#Vamos ver se o endereco mudou
	getip > ${TMPDIR}/ddns.ip.new
	  # Comparamos para ver se ele realmente mudou
	  if [ `cat ${TMPDIR}/ddns.ip.new` != `cat ${TMPDIR}/ddns.ip` ]; then
		# Trocamos o arquivo base pelo novo IP
		mv ${TMPDIR}/ddns.ip.new ${TMPDIR}/ddns.ip
		NEWIP=`cat ${TMPDIR}/ddns.ip`
		# Setamos o DDNS  com o novo IP
		setip $SENHA $DOMINIO $NEWIP
		if [ $? -ne 0 ]; then
			echo "0.0.0.0" >  ${TMPDIR}/ddns.ip   #isso vai forcar refresh
		fi
	  fi
}

check()
{
	if [ "$DOMINIO" = "" ]; then
		echo especique um dominio 
		exit
	fi

	if [ "$SENHA" = "" ]; then
		echo especique a senha
		exit
	fi

	count=0
	if [ "$IP" != "" ]; then
		count=$((count+1))
	fi

	if [ "$INTERFACE" != "" ]; then
		count=$((count+1))
	fi

	if [ "$USENAT" = "yes" ]; then
		count=$((count+1))
	fi

	if [ $count -lt 1 ]; then
		echo especique uma opcao dentre IP, INTERFACE e USENAT
		exit
	fi

	if [ $count -gt 1 ]; then
		echo especique apenas uma opcao dentre IP, INTERFACE e USENAT
		exit
	fi
}

	check

	if [ "$1" = "refresh" ]; then 
		refresh
	else
		setup
	fi
